@@ -1,4 +1,4 @@
-from typing import Dict, Optional
+from typing import Dict, Optional, Type
 
 import luigi
 
@@ -19,10 +19,10 @@ class inherits_config_params:
         self._config_class: luigi.Config = config_class
         self._parameter_alias: Dict[str, str] = parameter_alias if parameter_alias is not None else {}
 
-    def __call__(self, task: gokart.TaskOnKart):
+    def __call__(self, task_class: Type[gokart.TaskOnKart]):
         # wrap task to prevent task name from being changed
-        @luigi.task._task_wraps(task)
-        class Wrapped(task):
+        @luigi.task._task_wraps(task_class)
+        class Wrapped(task_class):
 
             @classmethod
             def get_param_values(cls, params, args, kwargs):
