@@ -11,7 +11,6 @@ from luigi.cmdline_parser import CmdlineParser
 import gokart
 import gokart.slack
 from gokart.object_storage import ObjectStorage
-from gokart.utils import check_config, read_environ
 
 logger = getLogger(__name__)
 
@@ -90,8 +89,6 @@ def run(cmdline_args=None, set_retcode=True):
         luigi.retcodes.retcode.task_failed = 40
         luigi.retcodes.retcode.scheduling_error = 50
 
-    read_environ()
-    check_config()
     _try_tree_info(cmdline_args)
     _try_to_delete_unnecessary_output_file(cmdline_args)
     gokart.testing.try_to_run_test_for_empty_data_frame(cmdline_args)
