@@ -8,6 +8,7 @@ from typing import Any, Callable, Dict, List, Optional, Set, Union
 
 import luigi
 import pandas as pd
+from luigi.parameter import ParameterVisibility
 
 import gokart
 from gokart.file_processor import FileProcessor
@@ -52,7 +53,10 @@ class TaskOnKart(luigi.Task):
                                       description='If this is false, this task is not treated as a part of dependent tasks for the unique id.',
                                       significant=False)
     fix_random_seed_methods = luigi.ListParameter(default=['random.seed', 'numpy.random.seed'], description='Fix random seed method list.', significant=False)
-    fix_random_seed_value = luigi.IntParameter(default=None, description='Fix random seed method value.', significant=False)
+    FIX_RANDOM_SEED_VALUE_NONE_MAGIC_NUMBER = -42497368
+    fix_random_seed_value = luigi.IntParameter(
+        default=FIX_RANDOM_SEED_VALUE_NONE_MAGIC_NUMBER, description='Fix random seed method value.',
+        significant=False)  # FIXME: should fix with OptionalIntParameter after newer luigi (https://github.com/spotify/luigi/pull/3079) will be released
 
     redis_host = luigi.OptionalParameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
     redis_port = luigi.OptionalParameter(default=None, description='Task lock check is deactivated, when None.', significant=False)
@@ -67,6 +71,11 @@ class TaskOnKart(luigi.Task):
                                                          significant=False)
 
     cache_unique_id: bool = ExplicitBoolParameter(default=True, description='Cache unique id during runtime', significant=False)
+    should_dump_supplementary_log_files: bool = ExplicitBoolParameter(
+        default=True,
+        description='Whether to dump supplementary files (task_log, random_seed, task_params, processing_time, module_versions) or not. \
+         Note that when set to False, task_info functions (e.g. gokart.tree.task_info.make_task_info_as_tree_str()) cannot be used.',
+        significant=False)
 
     def __init__(self, *args, **kwargs):
         self._add_configuration(kwargs, 'TaskOnKart')
@@ -261,10 +270,10 @@ class TaskOnKart(luigi.Task):
 
         required_columns = required_columns or set()
         if data.empty and len(data.index) == 0 and len(required_columns - set(data.columns)) > 0:
-            return pd.DataFrame(columns=required_columns)
+            return pd.DataFrame(columns=list(required_columns))
         assert required_columns.issubset(set(data.columns)), f'data must have columns {required_columns}, but actually have only {data.columns}.'
         if drop_columns:
-            data = data[required_columns]
+            data = data[list(required_columns)]
         return data
 
     def dump(self, obj, target: Union[None, str, TargetOnKart] = None) -> None:
@@ -350,7 +359,8 @@ class TaskOnKart(luigi.Task):
     @luigi.Task.event_handler(luigi.Event.SUCCESS)
     def _dump_task_log(self):
         self.task_log['file_path'] = [target.path() for target in luigi.task.flatten(self.output())]
-        self.dump(self.task_log, self._get_task_log_target())
+        if self.should_dump_supplementary_log_files:
+            self.dump(self.task_log, self._get_task_log_target())
 
     def _get_task_params_target(self):
         return self.make_target(f'log/task_params/{type(self).__name__}.pkl')
@@ -363,9 +373,10 @@ class TaskOnKart(luigi.Task):
 
     @luigi.Task.event_handler(luigi.Event.START)
     def _set_random_seed(self):
-        random_seed = self._get_random_seed()
-        seed_methods = self.try_set_seed(self.fix_random_seed_methods, random_seed)
-        self.dump({'seed': random_seed, 'seed_methods': seed_methods}, self._get_random_seeds_target())
+        if self.should_dump_supplementary_log_files:
+            random_seed = self._get_random_seed()
+            seed_methods = self.try_set_seed(self.fix_random_seed_methods, random_seed)
+            self.dump({'seed': random_seed, 'seed_methods': seed_methods}, self._get_random_seeds_target())
 
     def _get_random_seeds_target(self):
         return self.make_target(f'log/random_seed/{type(self).__name__}.pkl')
@@ -389,13 +400,14 @@ class TaskOnKart(luigi.Task):
         return success_methods
 
     def _get_random_seed(self):
-        if self.fix_random_seed_value:
+        if self.fix_random_seed_value and (not self.fix_random_seed_value == self.FIX_RANDOM_SEED_VALUE_NONE_MAGIC_NUMBER):
             return self.fix_random_seed_value
         return int(self.make_unique_id(), 16) % (2**32 - 1)  # maximum numpy.random.seed
 
     @luigi.Task.event_handler(luigi.Event.START)
     def _dump_task_params(self):
-        self.dump(self.to_str_params(only_significant=True), self._get_task_params_target())
+        if self.should_dump_supplementary_log_files:
+            self.dump(self.to_str_params(only_significant=True), self._get_task_params_target())
 
     def _get_processing_time_target(self):
         return self.make_target(f'log/processing_time/{type(self).__name__}.pkl')
@@ -408,7 +420,8 @@ class TaskOnKart(luigi.Task):
 
     @luigi.Task.event_handler(luigi.Event.PROCESSING_TIME)
     def _dump_processing_time(self, processing_time):
-        self.dump(processing_time, self._get_processing_time_target())
+        if self.should_dump_supplementary_log_files:
+            self.dump(processing_time, self._get_processing_time_target())
 
     @classmethod
     def restore(cls, unique_id):
@@ -421,7 +434,8 @@ class TaskOnKart(luigi.Task):
 
     @luigi.Task.event_handler(luigi.Event.START)
     def _dump_module_versions(self):
-        self.dump(self._get_module_versions(), self._get_module_versions_target())
+        if self.should_dump_supplementary_log_files:
+            self.dump(self._get_module_versions(), self._get_module_versions_target())
 
     def _get_module_versions_target(self):
         return self.make_target(f'log/module_versions/{type(self).__name__}.txt')
@@ -442,6 +456,19 @@ class TaskOnKart(luigi.Task):
         """
         Build a task representation like `MyTask(param1=1.5, param2='5', data_task=DataTask(id=35tyi))`
         """
+        return self._get_task_string()
+
+    def __str__(self):
+        """
+        Build a human-readable task representation like `MyTask(param1=1.5, param2='5', data_task=DataTask(id=35tyi))`
+        This includes only public parameters
+        """
+        return self._get_task_string(only_public=True)
+
+    def _get_task_string(self, only_public=False):
+        """
+        Convert a task representation like `MyTask(param1=1.5, param2='5', data_task=DataTask(id=35tyi))`
+        """
         params = self.get_params()
         param_values = self.get_param_values(params, [], self.param_kwargs)
 
@@ -450,7 +477,7 @@ class TaskOnKart(luigi.Task):
         param_objs = dict(params)
         for param_name, param_value in param_values:
             param_obj = param_objs[param_name]
-            if param_obj.significant:
+            if param_obj.significant and ((not only_public) or param_obj.visibility == ParameterVisibility.PUBLIC):
                 repr_parts.append(f'{param_name}={self._make_representation(param_obj, param_value)}')
 
         task_str = f'{self.get_task_family()}({", ".join(repr_parts)})'
